@@ -22,7 +22,6 @@
 
 #include <QApplication>
 #include <QComboBox>
-#include <QDebug>
 #include <QDialogButtonBox>
 #include <QGroupBox>
 #include <QLayout>
@@ -42,6 +41,7 @@
  */
 class KIconCanvasDelegate : public QAbstractItemDelegate
 {
+    Q_OBJECT
 public:
     KIconCanvasDelegate(KIconCanvas *parent, QAbstractItemDelegate *defaultDelegate);
     ~KIconCanvasDelegate() override {}
@@ -93,7 +93,7 @@ KIconCanvas::KIconCanvas(QWidget *parent)
     setUniformItemSizes(true);
     setMovement(Static);
     setIconSize(QSize(60, 60));
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(loadFiles()));
+    connect(m_timer, &QTimer::timeout, this, QOverload<>::of(&KIconCanvas::loadFiles));
     connect(this, &QListWidget::currentItemChanged,
             this, &KIconCanvas::currentListItemChanged);
     setGridSize(QSize(100, 80));
@@ -312,7 +312,7 @@ void KIconDialog::KIconDialogPrivate::init()
     // ADD SEARCHLINE
     //
     QHBoxLayout *searchLayout = new QHBoxLayout();
-    searchLayout->setMargin(0);
+    searchLayout->setContentsMargins(0, 0, 0, 0);
     top->addLayout(searchLayout);
 
     QLabel *searchLabel = new QLabel(i18n("&Search:"), q);
@@ -416,7 +416,7 @@ void KIconDialog::KIconDialogPrivate::_k_slotAcceptIcons()
 static bool sortByFileName(const QString &path1, const QString &path2)
 {
     const QString fileName1 = path1.mid(path1.lastIndexOf(QLatin1Char('/')) + 1);
-    const QString fileName2 = path2.mid(path1.lastIndexOf(QLatin1Char('/')) + 1);
+    const QString fileName2 = path2.mid(path2.lastIndexOf(QLatin1Char('/')) + 1);
     return QString::compare(fileName1, fileName2, Qt::CaseInsensitive) < 0;
 }
 
@@ -434,17 +434,19 @@ void KIconDialog::KIconDialogPrivate::showIcons()
         filelist = mpLoader->queryIconsByDir(customLocation);
     } else {
         // List PNG files found directly in the kiconload search paths.
-        Q_FOREACH (const QString &relDir, KIconLoader::global()->searchPaths()) {
+        const QStringList pngNameFilter(QStringLiteral("*.png"));
+        for (const QString &relDir : KIconLoader::global()->searchPaths()) {
             const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, relDir, QStandardPaths::LocateDirectory);
             for (const QString &dir : dirs) {
-                Q_FOREACH (const QString &fileName, QDir(dir).entryList(QStringList() << QLatin1String("*.png"))) {
+                const auto files = QDir(dir).entryList(pngNameFilter);
+                for (const QString &fileName : files) {
                     filelist << dir + QLatin1Char('/') + fileName;
                 }
             }
         }
     }
 
-    qSort(filelist.begin(), filelist.end(), sortByFileName);
+    std::sort(filelist.begin(), filelist.end(), sortByFileName);
 
     // The KIconCanvas has uniformItemSizes set which really expects
     // all added icons to be the same size, otherwise weirdness ensues :)
@@ -456,7 +458,7 @@ void KIconDialog::KIconDialogPrivate::showIcons()
         mpCanvas->setIconSize(QSize(-mGroupOrSize, -mGroupOrSize));
     } else {
         // Icon group.
-        int groupSize = mpLoader->currentSize((KIconLoader::Group)mGroupOrSize);
+        int groupSize = mpLoader->currentSize(static_cast<KIconLoader::Group>(mGroupOrSize));
         mpCanvas->setIconSize(QSize(groupSize, groupSize));
     }
 
@@ -660,5 +662,6 @@ void KIconDialog::KIconDialogPrivate::_k_slotFinished()
     mpProgress->hide();
 }
 
+#include "kicondialog.moc"
 #include "moc_kicondialog.cpp"
 #include "moc_kicondialog_p.cpp"
